@@ -45,7 +45,7 @@ The root of the derivatives directory in which the pipeline will store
 the processing results. If `None`, this will be
 `derivatives/mne-bids-pipeline` inside the BIDS root.
 
-Note: Note
+!!! info
     If specified and you wish to run the source analysis steps, you must
     set [`subjects_dir`][mne_bids_pipeline._config.subjects_dir] as well.
 """
@@ -65,7 +65,7 @@ FreeSurfer.
 If `None`, this will default to
 [`bids_root`][mne_bids_pipeline._config.bids_root]`/derivatives/freesurfer/subjects`.
 
-Note: Note
+!!! info
     This setting is required if you specify
     [`deriv_root`][mne_bids_pipeline._config.deriv_root]
     and want to run the source analysis steps.
@@ -78,7 +78,7 @@ figures. If running the steps from a notebook or Spyder,
 run `%matplotlib qt` in the command line to open the figures in a separate
 window.
 
-Note: Note
+!!! info
     Enabling interactive mode deactivates parallel processing.
 """
 
@@ -304,7 +304,7 @@ pairs. See the examples below.
 
 Can also be `None` if you do not want to create bipolar channels.
 
-Note: Note
+!!! info
     The channels used to create the bipolar channels are **not** automatically
     dropped from the data. To drop channels, set `drop_channels`.
 
@@ -540,7 +540,7 @@ use_maxwell_filter: bool = False
 """
 Whether or not to use Maxwell filtering to preprocess the data.
 
-warning:
+!!! warning
     If the data were recorded with internal active compensation (MaxShield),
     they need to be run through Maxwell filter to avoid distortions.
     Bad channels need to be set through BIDS channels.tsv and / or via the
@@ -614,11 +614,11 @@ runs. If `None`, pick the first run.
 
 mf_cal_fname: Optional[str] = None
 """
-warning:
+!!! warning
      This parameter should only be used for BIDS datasets that don't store
      the fine-calibration file
      [according to BIDS](https://bids-specification.readthedocs.io/en/stable/99-appendices/06-meg-file-formats.html#cross-talk-and-fine-calibration-files).
-Path to the Maxwell Filter calibration file. If None the recommended
+Path to the Maxwell Filter calibration file. If `None`, the recommended
 location is used.
 ???+ example "Example"
     ```python
@@ -628,9 +628,10 @@ location is used.
 
 mf_ctc_fname: Optional[str] = None
 """
-Path to the Maxwell Filter cross-talk file. If None the recommended
+Path to the Maxwell Filter cross-talk file. If `None`, the recommended
 location is used.
-warning:
+
+!!! warning
      This parameter should only be used for BIDS datasets that don't store
      the cross-talk file
      [according to BIDS](https://bids-specification.readthedocs.io/en/stable/99-appendices/06-meg-file-formats.html#cross-talk-and-fine-calibration-files).
@@ -697,7 +698,7 @@ notch_freq: Optional[Union[float, Iterable[float]]] = None
 Notch filter frequency. More than one frequency can be supplied, e.g. to remove
 harmonics. Keep it `None` if no notch filter should be applied.
 
-Note: Note
+!!! info
     The notch filter will be applied before high- and lowpass filtering.
 
 ???+ example "Example"
@@ -811,7 +812,7 @@ the order that events appear in `*_events.tsv`), pass `'drop'`. You can also
 request to create a new type of event by merging repeated events by setting
 this to `'merge'`.
 
-warning:
+!!! warning
     The `'merge'` option is entirely untested in the MNE BIDS Pipeline as of
     April 1st, 2021.
 """
@@ -1016,18 +1017,6 @@ epoched, and therefore the conditions should either match or be subsets of
     ```
 """
 
-report_evoked_n_time_points: Optional[int] = None
-"""
-Specifies the number of time points to display for each evoked
-in the report. If None it defaults to the current default in MNE-Python.
-
-???+ example "Example"
-    Only display 5 time points per evoked
-    ```python
-    report_evoked_n_time_points = 5
-    ```
-"""
-
 ###############################################################################
 # ARTIFACT REMOVAL
 # ----------------
@@ -1070,8 +1059,6 @@ Minimal number of EOG epochs needed to compute SSP or ICA rejection.
 
 # Rejection based on SSP
 # ~~~~~~~~~~~~~~~~~~~~~~
-
-
 n_proj_eog: Dict[str, float] = dict(n_mag=1, n_grad=1, n_eeg=1)
 """
 Number of SSP vectors to create for EOG artifacts for each channel type.
@@ -1141,11 +1128,8 @@ otherwise, SSP won't be able to "see" these artifacts.
     ```
 """
 
-
 # Rejection based on ICA
 # ~~~~~~~~~~~~~~~~~~~~~~
-
-
 ica_reject: Optional[Dict[str, float]] = None
 """
 Peak-to-peak amplitude limits to exclude epochs from ICA fitting.
@@ -1184,7 +1168,7 @@ data, yielding improved ICA results. Must be set to 1 Hz or above.
 
 Set to `None` to not apply an additional high-pass filter.
 
-Note: Note
+!!! info
       The filter will be applied to raw data which was already filtered
       according to the `l_freq` and `h_freq` settings. After filtering, the
       data will be epoched, and the epochs will be submitted to ICA.
@@ -1254,7 +1238,6 @@ that more ICs will be identified as EOG-related. If too low, the
 false-alarm rate increases dramatically.
 """
 
-
 # Rejection based on peak-to-peak amplitude
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
@@ -1275,7 +1258,7 @@ The thresholds provided here must be at least as stringent as those in
 `'autoreject_global'`, thresholds for any channel that do not meet this
 requirement will be automatically replaced with those used in `ica_reject`.
 
-Note: Note
+!!! info
       The rejection is performed **after** SSP or ICA, if any of those methods
       is used. To reject epochs **before** fitting ICA, see the
       [`ica_reject`][mne_bids_pipeline._config.ica_reject] setting.
@@ -1287,7 +1270,7 @@ rejection thresholds for each channel type, i.e. `autoreject` will generate
 a dictionary with (hopefully!) optimal thresholds for each channel type. Note
 that using `autoreject` can be a time-consuming process.
 
-Note: Note
+!!! info
       `autoreject` basically offers two modes of operation: "global" and
       "local". In "global" mode, it will try to estimate one rejection
       threshold **per channel type.** In "local" mode, it will generate
@@ -1328,7 +1311,7 @@ with the last time point.
 
 decode: bool = True
 """
-Whether to perform decoding (MVPA) on the contrasts specified above as
+Whether to perform decoding (MVPA) on the specified
 [`contrasts`][mne_bids_pipeline._config.contrasts]. Classifiers will be trained
 on entire epochs ("full-epochs decoding"), and separately on each time point
 ("time-by-time decoding"), trying to learn how to distinguish the contrasting
@@ -1338,7 +1321,7 @@ conditions.
 decoding_epochs_tmin: Optional[float] = 0.0
 """
 The first time sample to use for full epochs decoding. By default it starts
-at 0. If None, it starts at the beginning of the epoch.
+at 0. If `None`,, it starts at the beginning of the epoch.
 """
 
 decoding_epochs_tmax: Optional[float] = None
@@ -1407,7 +1390,7 @@ will be used to form clusters. If `None`, the threshold will be automatically
 determined to correspond to a p-value of 0.05 for the given number of
 participants in a one-tailed test.
 
-Note: Note
+!!! info
     Only points with the same sign will be clustered together.
 """
 
@@ -1423,7 +1406,7 @@ The alpha level (p-value, p threshold) to use for rejecting the null hypothesis
 that the clusters show no significant difference between conditions. This is
 used in the permutation test which takes place after forming the clusters.
 
-Note: Note
+!!! info
     To control how clusters are formed, see
     [`cluster_forming_t_threshold`][mne_bids_pipeline._config.cluster_forming_t_threshold].
 """
@@ -1492,7 +1475,7 @@ Whether to subtract the evoked signal (averaged across all epochs) from the
 epochs before passing them to time-frequency analysis. Set this to `True` to
 highlight induced activity.
 
-Note: Note
+!!! info
      This also applies to CSP analysis.
 """
 
@@ -1726,7 +1709,7 @@ electrophysiological data:
 This `BIDSPath` can then be modified – or an entirely new `BIDSPath` can be
 generated – and returned by the function, pointing to the T1-weighted image.
 
-Note: Note
+!!! info
     The function accepts and returns a single `BIDSPath`.
 
 ???+ example "Example"
@@ -1915,10 +1898,26 @@ empty list, `[]`.
     ```
 """
 
+###############################################################################
+# Report generation
+# -----------------
+
+report_evoked_n_time_points: Optional[int] = None
+"""
+Specifies the number of time points to display for each evoked
+in the report. If `None`, it defaults to the current default in MNE-Python.
+
+???+ example "Example"
+    Only display 5 time points per evoked
+    ```python
+    report_evoked_n_time_points = 5
+    ```
+"""
+
 report_stc_n_time_points: Optional[int] = None
 """
 Specifies the number of time points to display for each source estimates
-in the report. If None it defaults to the current default in MNE-Python.
+in the report. If `None`, it defaults to the current default in MNE-Python.
 
 ???+ example "Example"
     Only display 5 images per source estimate:
@@ -1999,7 +1998,7 @@ Whether to abort processing as soon as an error occurs, continue with all other
 processing steps for as long as possible, or drop you into a debugger in case
 of an error.
 
-Note: Note
+!!! info
     Enabling debug mode deactivates parallel processing.
 """
 
