@@ -3,7 +3,7 @@
 import copy
 import functools
 import pathlib
-from typing import List, Optional, Union, Iterable, Tuple, Dict, TypeVar, Literal
+from typing import List, Optional, Union, Iterable, Tuple, Dict, TypeVar, Literal, Any
 from types import SimpleNamespace, ModuleType
 
 import numpy as np
@@ -65,13 +65,21 @@ def get_datatype(config: SimpleNamespace) -> Literal["meg", "eeg"]:
         return "meg"
     else:
         raise RuntimeError(
-            "This probably shouldn't happen. Please contact "
+            "This probably shouldn't happen, got "
+            f"config.data_type={repr(config.data_type)} and "
+            f"config.ch_types={repr(config.ch_types)} "
+            "but could not determine the datatype. Please contact "
             "the MNE-BIDS-pipeline developers. Thank you."
         )
 
 
+@functools.lru_cache(maxsize=None)
+def _get_datatypes_cached(root):
+    return mne_bids.get_datatypes(root=root)
+
+
 def _get_ignore_datatypes(config: SimpleNamespace) -> Tuple[str]:
-    _all_datatypes: List[str] = mne_bids.get_datatypes(root=config.bids_root)
+    _all_datatypes: List[str] = _get_datatypes_cached(root=config.bids_root)
     _ignore_datatypes = set(_all_datatypes) - set([get_datatype(config)])
     return tuple(sorted(_ignore_datatypes))
 
@@ -110,6 +118,16 @@ def get_sessions(config: SimpleNamespace) -> Union[List[None], List[str]]:
         return sessions
 
 
+@functools.lru_cache(maxsize=None)
+def _get_runs_all_subjects_cached(
+    **config_dict: Dict[str, Any],
+) -> Dict[str, Union[List[None], List[str]]]:
+    config = SimpleNamespace(**config_dict)
+    # Sometimes we check list equivalence for ch_types, so convert it back
+    config.ch_types = list(config.ch_types)
+    return get_runs_all_subjects(config)
+
+
 def get_runs_all_subjects(
     config: SimpleNamespace,
 ) -> Dict[str, Union[List[None], List[str]]]:
@@ -173,7 +191,14 @@ def get_runs(
 
     runs = copy.deepcopy(config.runs)
 
-    subj_runs = get_runs_all_subjects(config)
+    subj_runs = _get_runs_all_subjects_cached(
+        bids_root=config.bids_root,
+        data_type=config.data_type,
+        ch_types=tuple(config.ch_types),
+        subjects=tuple(config.subjects) if config.subjects != "all" else "all",
+        exclude_subjects=tuple(config.exclude_subjects),
+        exclude_runs=tuple(config.exclude_runs) if config.exclude_runs else None,
+    )
     valid_runs = subj_runs[subject]
 
     if len(get_subjects(config)) > 1:
@@ -227,7 +252,7 @@ def get_mf_reference_run(config: SimpleNamespace) -> str:
         raise ValueError(
             f"The intersection of runs by subjects is empty. "
             f"Check the list of runs: "
-            f"{get_runs_all_subjects()}"
+            f"{get_runs_all_subjects(config)}"
         )
 
 
