@@ -17,24 +17,27 @@ from sklearn.model_selection import StratifiedKFold, cross_val_score
 from sklearn.pipeline import make_pipeline
 
 from ..._config_utils import (
-    get_sessions, get_subjects, get_task, get_datatype, get_eeg_reference,
-    _restrict_analyze_channels, get_decoding_contrasts,
+    get_sessions,
+    get_subjects,
+    get_task,
+    get_datatype,
+    get_eeg_reference,
+    _restrict_analyze_channels,
+    get_decoding_contrasts,
 )
 from ..._decoding import LogReg, _handle_csp_args
 from ..._logging import logger, gen_log_kwargs
 from ..._parallel import parallel_func, get_parallel_backend
 from ..._run import failsafe_run, save_logs
 from ..._report import (
-    _open_report, _sanitize_cond_tag, _plot_full_epochs_decoding_scores,
+    _open_report,
+    _sanitize_cond_tag,
+    _plot_full_epochs_decoding_scores,
     _imshow_tf,
 )
 
 
-def _prepare_labels(
-    *,
-    epochs: mne.BaseEpochs,
-    contrast: Tuple[str, str]
-) -> np.ndarray:
+def _prepare_labels(*, epochs: mne.BaseEpochs, contrast: Tuple[str, str]) -> np.ndarray:
     """Return the projection of the events_id on a boolean vector.
 
     This projection is useful in the case of hierarchical events:
@@ -53,10 +56,12 @@ def _prepare_labels(
     y = epochs.events[:, 2].copy()
     for i in range(len(y)):
         if y[i] in event_codes_condition_0 and y[i] in event_codes_condition_1:
-            msg = (f"Event_id {y[i]} is contained both in "
-                   f"{contrast[0]}'s set {event_codes_condition_0} and in "
-                   f"{contrast[1]}'s set {event_codes_condition_1}."
-                   f"{contrast} does not constitute a valid partition.")
+            msg = (
+                f"Event_id {y[i]} is contained both in "
+                f"{contrast[0]}'s set {event_codes_condition_0} and in "
+                f"{contrast[1]}'s set {event_codes_condition_1}."
+                f"{contrast} does not constitute a valid partition."
+            )
             raise RuntimeError(msg)
         elif y[i] in event_codes_condition_0:
             y[i] = 0
@@ -64,48 +69,42 @@ def _prepare_labels(
             y[i] = 1
         else:
             # This should not happen because epochs should already be filtered
-            msg = (f"Event_id {y[i]} is not contained in "
-                   f"{contrast[0]}'s set {event_codes_condition_0}  nor in "
-                   f"{contrast[1]}'s set {event_codes_condition_1}.")
+            msg = (
+                f"Event_id {y[i]} is not contained in "
+                f"{contrast[0]}'s set {event_codes_condition_0}  nor in "
+                f"{contrast[1]}'s set {event_codes_condition_1}."
+            )
             raise RuntimeError(msg)
     return y
 
 
 def prepare_epochs_and_y(
-    *,
-    epochs: mne.BaseEpochs,
-    contrast: Tuple[str, str],
-    cfg,
-    fmin: float,
-    fmax: float
+    *, epochs: mne.BaseEpochs, contrast: Tuple[str, str], cfg, fmin: float, fmax: float
 ) -> Tuple[mne.BaseEpochs, np.ndarray]:
     """Band-pass between, sub-select the desired epochs, and prepare y."""
-    epochs_filt = (
-        epochs
-        .copy()
-        .pick_types(
-            meg=True, eeg=True,
-        )
+    epochs_filt = epochs.copy().pick_types(
+        meg=True,
+        eeg=True,
     )
 
     # We only take mag to speed up computation
     # because the information is redundant between grad and mag
-    if cfg.datatype == 'meg' and cfg.use_maxwell_filter:
-        epochs_filt.pick_types(meg='mag')
+    if cfg.datatype == "meg" and cfg.use_maxwell_filter:
+        epochs_filt.pick_types(meg="mag")
 
     # filtering out the conditions we are not interested in, to ensure here we
     # have a valid partition between the condition of the contrast.
     #
     # XXX Hack for handling epochs selection via metadata
-    if contrast[0].startswith('event_name.isin'):
-        epochs_filt = epochs_filt[f'{contrast[0]} or {contrast[1]}']
+    if contrast[0].startswith("event_name.isin"):
+        epochs_filt = epochs_filt[f"{contrast[0]} or {contrast[1]}"]
     else:
         epochs_filt = epochs_filt[contrast]
 
     # Filtering is costly, so do it last, after the selection of the channels
     # and epochs. We know that often the filter will be longer than the signal,
     # so we ignore the warning here.
-    epochs_filt = epochs_filt.filter(fmin, fmax, n_jobs=1, verbose='error')
+    epochs_filt = epochs_filt.filter(fmin, fmax, n_jobs=1, verbose="error")
     y = _prepare_labels(epochs=epochs_filt, contrast=contrast)
 
     return epochs_filt, y
@@ -118,26 +117,26 @@ def get_input_fnames_csp(
     session: Optional[str],
     contrast: Tuple[str],
 ) -> dict:
-    fname_epochs = BIDSPath(subject=subject,
-                            session=session,
-                            task=cfg.task,
-                            acquisition=cfg.acq,
-                            run=None,
-                            recording=cfg.rec,
-                            space=cfg.space,
-                            suffix='epo',
-                            extension='.fif',
-                            datatype=cfg.datatype,
-                            root=cfg.deriv_root,
-                            check=False)
+    fname_epochs = BIDSPath(
+        subject=subject,
+        session=session,
+        task=cfg.task,
+        acquisition=cfg.acq,
+        run=None,
+        recording=cfg.rec,
+        space=cfg.space,
+        suffix="epo",
+        extension=".fif",
+        datatype=cfg.datatype,
+        root=cfg.deriv_root,
+        check=False,
+    )
     in_files = dict()
-    in_files['epochs'] = fname_epochs
+    in_files["epochs"] = fname_epochs
     return in_files
 
 
-@failsafe_run(
-    get_input_fnames=get_input_fnames_csp
-)
+@failsafe_run(get_input_fnames=get_input_fnames_csp)
 def one_subject_decoding(
     *,
     cfg: SimpleNamespace,
@@ -145,7 +144,7 @@ def one_subject_decoding(
     subject: str,
     session: str,
     contrast: Tuple[str, str],
-    in_files: Dict[str, BIDSPath]
+    in_files: Dict[str, BIDSPath],
 ) -> dict:
     """Run one subject.
 
@@ -154,12 +153,13 @@ def one_subject_decoding(
     2. The time-frequency analysis.
     """
     import matplotlib.pyplot as plt
+
     condition1, condition2 = contrast
-    msg = f'Contrasting conditions: {condition1} – {condition2}'
+    msg = f"Contrasting conditions: {condition1} – {condition2}"
     logger.info(**gen_log_kwargs(msg))
 
-    bids_path = in_files['epochs'].copy().update(processing=None)
-    epochs = mne.read_epochs(in_files.pop('epochs'))
+    bids_path = in_files["epochs"].copy().update(processing=None)
+    epochs = mne.read_epochs(in_files.pop("epochs"))
     _restrict_analyze_channels(epochs, cfg)
 
     if cfg.time_frequency_subtract_evoked:
@@ -169,34 +169,28 @@ def one_subject_decoding(
     #
     # Select the channel type with the smallest rank.
     # Limit it to a maximum of 100.
-    ranks = mne.compute_rank(inst=epochs, rank='info')
+    ranks = mne.compute_rank(inst=epochs, rank="info")
     ch_type_smallest_rank = min(ranks, key=ranks.get)
-    rank = min(
-        ranks[ch_type_smallest_rank],
-        100
-    )
+    rank = min(ranks[ch_type_smallest_rank], 100)
     del ch_type_smallest_rank, ranks
 
-    msg = f'Reducing data dimension via PCA; new rank: {rank}.'
+    msg = f"Reducing data dimension via PCA; new rank: {rank}."
     logger.info(**gen_log_kwargs(msg))
-    pca = UnsupervisedSpatialFilter(
-        PCA(rank),
-        average=False
-    )
+    pca = UnsupervisedSpatialFilter(PCA(rank), average=False)
 
     # Classifier
     csp = CSP(
         n_components=4,  # XXX revisit
-        reg=0.1,         # XXX revisit
-        rank='info',
+        reg=0.1,  # XXX revisit
+        rank="info",
     )
     clf = make_pipeline(
         csp,
         LogReg(
-            solver='liblinear',  # much faster than the default
+            solver="liblinear",  # much faster than the default
             random_state=cfg.random_state,
             n_jobs=1,
-        )
+        ),
     )
     cv = StratifiedKFold(
         n_splits=cfg.decoding_n_splits,
@@ -206,46 +200,46 @@ def one_subject_decoding(
 
     # Loop over frequencies (all time points lumped together)
     freq_name_to_bins_map = _handle_csp_args(
-        cfg.decoding_csp_times, cfg.decoding_csp_freqs, cfg.decoding_metric)
+        cfg.decoding_csp_times, cfg.decoding_csp_freqs, cfg.decoding_metric
+    )
     freq_decoding_table_rows = []
     for freq_range_name, freq_bins in freq_name_to_bins_map.items():
         for freq_bin in freq_bins:
             f_min, f_max = freq_bin
             row = {
-                'subject': [subject],
-                'cond_1': [condition1],
-                'cond_2': [condition2],
-                'f_min': [f_min],
-                'f_max': [f_max],
-                'freq_range_name': [freq_range_name],
-                'mean_crossval_score': [np.nan],
-                'scores': [np.ones(5)],
-                'metric': [cfg.decoding_metric],
+                "subject": [subject],
+                "cond_1": [condition1],
+                "cond_2": [condition2],
+                "f_min": [f_min],
+                "f_max": [f_max],
+                "freq_range_name": [freq_range_name],
+                "mean_crossval_score": [np.nan],
+                "scores": [np.ones(5)],
+                "metric": [cfg.decoding_metric],
             }
             freq_decoding_table_rows.append(row)
 
     freq_decoding_table = pd.concat(
         [pd.DataFrame.from_dict(row) for row in freq_decoding_table_rows],
-        ignore_index=True
+        ignore_index=True,
     )
     del freq_decoding_table_rows
 
-    def _fmt_contrast(cond1, cond2, fmin, fmax, freq_range_name,
-                      tmin=None, tmax=None):
+    def _fmt_contrast(cond1, cond2, fmin, fmax, freq_range_name, tmin=None, tmax=None):
         msg = (
-            f'Contrast: {cond1} – {cond2}, '
-            f'{fmin:4.1f}–{fmax:4.1f} Hz ({freq_range_name})'
+            f"Contrast: {cond1} – {cond2}, "
+            f"{fmin:4.1f}–{fmax:4.1f} Hz ({freq_range_name})"
         )
         if tmin is not None:
-            msg += f' {tmin:+5.3f}–{tmax:+5.3f} sec'
+            msg += f" {tmin:+5.3f}–{tmax:+5.3f} sec"
         return msg
 
     for idx, row in freq_decoding_table.iterrows():
-        fmin = row['f_min']
-        fmax = row['f_max']
-        cond1 = row['cond_1']
-        cond2 = row['cond_2']
-        freq_range_name = row['freq_range_name']
+        fmin = row["f_min"]
+        fmax = row["f_max"]
+        cond1 = row["cond_1"]
+        cond2 = row["cond_2"]
+        freq_range_name = row["freq_range_name"]
 
         msg = _fmt_contrast(cond1, cond2, fmin, fmax, freq_range_name)
         logger.info(**gen_log_kwargs(msg))
@@ -272,8 +266,8 @@ def one_subject_decoding(
             cv=cv,
             n_jobs=1,
         )
-        freq_decoding_table.loc[idx, 'mean_crossval_score'] = cv_scores.mean()
-        freq_decoding_table.at[idx, 'scores'] = cv_scores
+        freq_decoding_table.loc[idx, "mean_crossval_score"] = cv_scores.mean()
+        freq_decoding_table.at[idx, "scores"] = cv_scores
 
     # Loop over times x frequencies
     #
@@ -281,9 +275,7 @@ def one_subject_decoding(
     # ranges to avoid leaking of information.
     time_bins = np.array(cfg.decoding_csp_times)
     if time_bins.ndim == 1:
-        time_bins = np.array(
-            list(zip(time_bins[:-1], time_bins[1:]))
-        )
+        time_bins = np.array(list(zip(time_bins[:-1], time_bins[1:])))
     assert time_bins.ndim == 2
 
     tf_decoding_table_rows = []
@@ -295,34 +287,34 @@ def one_subject_decoding(
             for freq_bin in freq_bins:
                 f_min, f_max = freq_bin
                 row = {
-                    'subject': [subject],
-                    'cond_1': [condition1],
-                    'cond_2': [condition2],
-                    't_min': [t_min],
-                    't_max': [t_max],
-                    'f_min': [f_min],
-                    'f_max': [f_max],
-                    'freq_range_name': [freq_range_name],
-                    'mean_crossval_score': [np.nan],
-                    'scores': [np.ones(5, dtype=float)],
-                    'metric': [cfg.decoding_metric]
+                    "subject": [subject],
+                    "cond_1": [condition1],
+                    "cond_2": [condition2],
+                    "t_min": [t_min],
+                    "t_max": [t_max],
+                    "f_min": [f_min],
+                    "f_max": [f_max],
+                    "freq_range_name": [freq_range_name],
+                    "mean_crossval_score": [np.nan],
+                    "scores": [np.ones(5, dtype=float)],
+                    "metric": [cfg.decoding_metric],
                 }
                 tf_decoding_table_rows.append(row)
 
     tf_decoding_table = pd.concat(
         [pd.DataFrame.from_dict(row) for row in tf_decoding_table_rows],
-        ignore_index=True
+        ignore_index=True,
     )
     del tf_decoding_table_rows
 
     for idx, row in tf_decoding_table.iterrows():
-        tmin = row['t_min']
-        tmax = row['t_max']
-        fmin = row['f_min']
-        fmax = row['f_max']
-        cond1 = row['cond_1']
-        cond2 = row['cond_2']
-        freq_range_name = row['freq_range_name']
+        tmin = row["t_min"]
+        tmax = row["t_max"]
+        fmin = row["f_min"]
+        fmax = row["f_max"]
+        cond1 = row["cond_1"]
+        cond2 = row["cond_2"]
+        freq_range_name = row["freq_range_name"]
 
         epochs_filt, y = prepare_epochs_and_y(
             epochs=epochs, contrast=contrast, fmin=fmin, fmax=fmax, cfg=cfg
@@ -344,39 +336,32 @@ def one_subject_decoding(
             n_jobs=1,
         )
         score = cv_scores.mean()
-        tf_decoding_table.loc[idx, 'mean_crossval_score'] = score
-        tf_decoding_table.at[idx, 'scores'] = cv_scores
-        msg = _fmt_contrast(
-            cond1, cond2, fmin, fmax, freq_range_name, tmin, tmax)
-        msg += f': {cfg.decoding_metric}={score:0.3f}'
+        tf_decoding_table.loc[idx, "mean_crossval_score"] = score
+        tf_decoding_table.at[idx, "scores"] = cv_scores
+        msg = _fmt_contrast(cond1, cond2, fmin, fmax, freq_range_name, tmin, tmax)
+        msg += f": {cfg.decoding_metric}={score:0.3f}"
         logger.info(**gen_log_kwargs(msg))
 
     # Write each DataFrame to a different Excel worksheet.
-    a_vs_b = f'{condition1}+{condition2}'.replace(op.sep, '')
-    processing = f'{a_vs_b}+CSP+{cfg.decoding_metric}'
-    processing = processing.replace('_', '-').replace('-', '')
+    a_vs_b = f"{condition1}+{condition2}".replace(op.sep, "")
+    processing = f"{a_vs_b}+CSP+{cfg.decoding_metric}"
+    processing = processing.replace("_", "-").replace("-", "")
 
-    fname_results = bids_path.copy().update(suffix='decoding',
-                                            processing=processing,
-                                            extension='.xlsx')
+    fname_results = bids_path.copy().update(
+        suffix="decoding", processing=processing, extension=".xlsx"
+    )
     with pd.ExcelWriter(fname_results) as w:
-        freq_decoding_table.to_excel(
-            w, sheet_name='CSP Frequency', index=False
-        )
-        tf_decoding_table.to_excel(
-            w, sheet_name='CSP Time-Frequency', index=False
-        )
-    out_files = {'csp-excel': fname_results}
+        freq_decoding_table.to_excel(w, sheet_name="CSP Frequency", index=False)
+        tf_decoding_table.to_excel(w, sheet_name="CSP Time-Frequency", index=False)
+    out_files = {"csp-excel": fname_results}
 
     # Report
     with _open_report(
-            cfg=cfg,
-            exec_params=exec_params,
-            subject=subject,
-            session=session) as report:
-        msg = 'Adding CSP decoding results to the report.'
+        cfg=cfg, exec_params=exec_params, subject=subject, session=session
+    ) as report:
+        msg = "Adding CSP decoding results to the report."
         logger.info(**gen_log_kwargs(message=msg))
-        section = 'Decoding: CSP'
+        section = "Decoding: CSP"
         freq_name_to_bins_map = _handle_csp_args(
             cfg.decoding_csp_times,
             cfg.decoding_csp_freqs,
@@ -385,35 +370,31 @@ def one_subject_decoding(
         all_csp_tf_results = dict()
         for contrast in cfg.decoding_contrasts:
             cond_1, cond_2 = contrast
-            a_vs_b = f'{cond_1}+{cond_2}'.replace(op.sep, '')
+            a_vs_b = f"{cond_1}+{cond_2}".replace(op.sep, "")
             tags = (
-                'epochs',
-                'contrast',
-                'decoding',
-                'csp',
-                f"{_sanitize_cond_tag(cond_1)}–{_sanitize_cond_tag(cond_2)}"
+                "epochs",
+                "contrast",
+                "decoding",
+                "csp",
+                f"{_sanitize_cond_tag(cond_1)}–{_sanitize_cond_tag(cond_2)}",
             )
-            processing = f'{a_vs_b}+CSP+{cfg.decoding_metric}'
-            processing = processing.replace('_', '-').replace('-', '')
+            processing = f"{a_vs_b}+CSP+{cfg.decoding_metric}"
+            processing = processing.replace("_", "-").replace("-", "")
             fname_decoding = bids_path.copy().update(
-                processing=processing,
-                suffix='decoding',
-                extension='.xlsx'
+                processing=processing, suffix="decoding", extension=".xlsx"
             )
             if not fname_decoding.fpath.is_file():
                 continue  # not done yet
-            csp_freq_results = pd.read_excel(
-                fname_decoding,
-                sheet_name='CSP Frequency'
+            csp_freq_results = pd.read_excel(fname_decoding, sheet_name="CSP Frequency")
+            csp_freq_results["scores"] = csp_freq_results["scores"].apply(
+                lambda x: np.array(x[1:-1].split(), float)
             )
-            csp_freq_results['scores'] = csp_freq_results['scores'].apply(
-                lambda x: np.array(x[1:-1].split(), float))
             csp_tf_results = pd.read_excel(
-                fname_decoding,
-                sheet_name='CSP Time-Frequency'
+                fname_decoding, sheet_name="CSP Time-Frequency"
+            )
+            csp_tf_results["scores"] = csp_tf_results["scores"].apply(
+                lambda x: np.array(x[1:-1].split(), float)
             )
-            csp_tf_results['scores'] = csp_tf_results['scores'].apply(
-                lambda x: np.array(x[1:-1].split(), float))
             all_csp_tf_results[contrast] = csp_tf_results
             del csp_tf_results
 
@@ -421,24 +402,23 @@ def one_subject_decoding(
             contrast_names = list()
             for freq_range_name, freq_bins in freq_name_to_bins_map.items():
                 results = csp_freq_results.loc[
-                    csp_freq_results['freq_range_name'] == freq_range_name
+                    csp_freq_results["freq_range_name"] == freq_range_name
                 ]
                 results.reset_index(drop=True, inplace=True)
-                assert len(results['scores']) == len(freq_bins)
+                assert len(results["scores"]) == len(freq_bins)
                 for bi, freq_bin in enumerate(freq_bins):
-                    all_decoding_scores.append(results['scores'][bi])
+                    all_decoding_scores.append(results["scores"][bi])
                     f_min = float(freq_bin[0])
                     f_max = float(freq_bin[1])
                     contrast_names.append(
-                        f'{freq_range_name}\n'
-                        f'({f_min:0.1f}-{f_max:0.1f} Hz)'
+                        f"{freq_range_name}\n" f"({f_min:0.1f}-{f_max:0.1f} Hz)"
                     )
             fig, caption = _plot_full_epochs_decoding_scores(
                 contrast_names=contrast_names,
                 scores=all_decoding_scores,
                 metric=cfg.decoding_metric,
             )
-            title = f'CSP decoding: {cond_1} vs. {cond_2}'
+            title = f"CSP decoding: {cond_1} vs. {cond_2}"
             report.add_figure(
                 fig=fig,
                 title=title,
@@ -457,50 +437,65 @@ def one_subject_decoding(
                 continue
             cond_1, cond_2 = contrast
             tags = (
-                'epochs',
-                'contrast',
-                'decoding',
-                'csp',
+                "epochs",
+                "contrast",
+                "decoding",
+                "csp",
                 f"{_sanitize_cond_tag(cond_1)}–{_sanitize_cond_tag(cond_2)}",
             )
             results = all_csp_tf_results[contrast]
             mean_crossval_scores = list()
             tmin, tmax, fmin, fmax = list(), list(), list(), list()
-            mean_crossval_scores.extend(
-                results['mean_crossval_score'].ravel())
-            tmin.extend(results['t_min'].ravel())
-            tmax.extend(results['t_max'].ravel())
-            fmin.extend(results['f_min'].ravel())
-            fmax.extend(results['f_max'].ravel())
+            mean_crossval_scores.extend(results["mean_crossval_score"].ravel())
+            tmin.extend(results["t_min"].ravel())
+            tmax.extend(results["t_max"].ravel())
+            fmin.extend(results["f_min"].ravel())
+            fmax.extend(results["f_max"].ravel())
             mean_crossval_scores = np.array(mean_crossval_scores, float)
             fig, ax = plt.subplots(constrained_layout=True)
             # XXX Add support for more metrics
-            assert cfg.decoding_metric == 'roc_auc'
-            metric = 'ROC AUC'
-            vmax = max(
-                np.abs(mean_crossval_scores.min() - 0.5),
-                np.abs(mean_crossval_scores.max() - 0.5)
-            ) + 0.5
+            assert cfg.decoding_metric == "roc_auc"
+            metric = "ROC AUC"
+            vmax = (
+                max(
+                    np.abs(mean_crossval_scores.min() - 0.5),
+                    np.abs(mean_crossval_scores.max() - 0.5),
+                )
+                + 0.5
+            )
             vmin = 0.5 - (vmax - 0.5)
             img = _imshow_tf(
-                mean_crossval_scores, ax,
-                tmin=tmin, tmax=tmax, fmin=fmin, fmax=fmax,
-                vmin=vmin, vmax=vmax)
+                mean_crossval_scores,
+                ax,
+                tmin=tmin,
+                tmax=tmax,
+                fmin=fmin,
+                fmax=fmax,
+                vmin=vmin,
+                vmax=vmax,
+            )
             offset = matplotlib.transforms.offset_copy(
-                ax.transData, fig, 6, 0, units='points')
+                ax.transData, fig, 6, 0, units="points"
+            )
             for freq_range_name, bins in freq_name_to_bins_map.items():
-                ax.text(tmin[0],
-                        0.5 * bins[0][0] + 0.5 * bins[-1][1],
-                        freq_range_name, transform=offset,
-                        ha='left', va='center', rotation=90)
+                ax.text(
+                    tmin[0],
+                    0.5 * bins[0][0] + 0.5 * bins[-1][1],
+                    freq_range_name,
+                    transform=offset,
+                    ha="left",
+                    va="center",
+                    rotation=90,
+                )
             ax.set_xlim([np.min(tmin), np.max(tmax)])
             ax.set_ylim([np.min(fmin), np.max(fmax)])
-            ax.set_xlabel('Time (s)')
-            ax.set_ylabel('Frequency (Hz)')
+            ax.set_xlabel("Time (s)")
+            ax.set_ylabel("Frequency (Hz)")
             cbar = fig.colorbar(
-                ax=ax, shrink=0.75, orientation='vertical', mappable=img)
-            cbar.set_label(f'Mean decoding score ({metric})')
-            title = f'CSP TF decoding: {cond_1} vs. {cond_2}'
+                ax=ax, shrink=0.75, orientation="vertical", mappable=img
+            )
+            cbar.set_label(f"Mean decoding score ({metric})")
+            title = f"CSP TF decoding: {cond_1} vs. {cond_2}"
             report.add_figure(
                 fig=fig,
                 title=title,
@@ -514,10 +509,7 @@ def one_subject_decoding(
 
 
 def get_config(
-    *,
-    config: SimpleNamespace,
-    subject: str,
-    session: Optional[str]
+    *, config: SimpleNamespace, subject: str, session: Optional[str]
 ) -> SimpleNamespace:
     cfg = SimpleNamespace(
         # Data parameters
@@ -548,24 +540,21 @@ def main(*, config: SimpleNamespace) -> None:
     """Run all subjects decoding in parallel."""
     if not config.contrasts or not config.decoding_csp:
         if not config.contrasts:
-            msg = 'No contrasts specified. '
+            msg = "No contrasts specified. "
         else:
-            msg = 'No CSP analysis requested. '
+            msg = "No CSP analysis requested. "
 
-        msg = 'Skipping …'
-        logger.info(**gen_log_kwargs(message=msg, emoji='skip'))
+        msg = "Skipping …"
+        logger.info(**gen_log_kwargs(message=msg, emoji="skip"))
         return
 
     with get_parallel_backend(config.exec_params):
         parallel, run_func = parallel_func(
-            one_subject_decoding, exec_params=config.exec_params)
+            one_subject_decoding, exec_params=config.exec_params
+        )
         logs = parallel(
             run_func(
-                cfg=get_config(
-                    config=config,
-                    subject=subject,
-                    session=session
-                ),
+                cfg=get_config(config=config, subject=subject, session=session),
                 exec_params=config.exec_params,
                 subject=subject,
                 session=session,
