@@ -1,29 +1,29 @@
 """
 hMT+ Localizer
 """
-study_name = 'localizer'
-bids_root = '~/mne_data/ds003392'
-deriv_root = '~/mne_data/derivatives/mne-bids-pipeline/ds003392'
+study_name = "localizer"
+bids_root = "~/mne_data/ds003392"
+deriv_root = "~/mne_data/derivatives/mne-bids-pipeline/ds003392"
 
-subjects = ['01']
+subjects = ["01"]
 
-task = 'localizer'
+task = "localizer"
 find_flat_channels_meg = True
 find_noisy_channels_meg = True
 use_maxwell_filter = True
-ch_types = ['meg']
+ch_types = ["meg"]
 
-l_freq = 1.
-h_freq = 40.
-resample_sfreq = 250
+l_freq = 1.0
+h_freq = 40.0
+raw_resample_sfreq = 250
 crop_runs = (0, 180)
 
 # Artifact correction.
-spatial_filter = 'ica'
+spatial_filter = "ica"
 ica_max_iterations = 500
-ica_l_freq = 1.
+ica_l_freq = 1.0
 ica_n_components = 0.99
-ica_reject_components = 'auto'
+ica_reject_components = "auto"
 
 # Epochs
 epochs_tmin = -0.2
@@ -31,13 +31,13 @@ epochs_tmax = 1.0
 baseline = (None, 0)
 
 # Conditions / events to consider when epoching
-conditions = ['coherent', 'incoherent']
+conditions = ["coherent", "incoherent"]
 
 # Decoding
 decode = True
 decoding_time_generalization = True
 decoding_time_generalization_decim = 4
-contrasts = [('incoherent', 'coherent')]
+contrasts = [("incoherent", "coherent")]
 
 # Noise estimation
-noise_cov = 'emptyroom'
+noise_cov = "emptyroom"
